@@ -83,6 +83,12 @@ def Character_To_Code(Character):
 def Code_To_Character(Code):
   return chr(Code)
 
+def Uppercase(Message):
+  return Message.upper()
+
+def Lowercase(Message):
+  return Message.lower()
+
 def Is_Uppercase(Message):
   return Message.isupper()
 
@@ -107,6 +113,12 @@ def Or(Bool_One, Bool_Two):
 def Not(Bool):
   return not Bool
 
+def Equal(Bool_One, Bool_Two):
+  return Bool_One == Bool_Two
+
+def Not_Equal(Bool_One, Bool_Two):
+  return Bool_One != Bool_Two
+
 def Print_Multiple_Times(Count, Msg):
   For_Loop(Range(Count), lambda Message: Print(Message), Msg)
 
@@ -131,11 +143,11 @@ def Multiply_Multiple_Numbers(*Numbers):
 def Get_Input_From_User(Message, Type = String):
   return Return_Value_Of(Type(input(Message)))
 
-def If_Selection(Condition, True_Code, False_Code = lambda: none):
+def If_Selection(Condition, True_Code, True_Argument_List = [], False_Code = lambda: none, False_Argument_List = []):
   if Condition:
-    True_Code()
+    True_Code(*True_Argument_List)
   else:
-    False_Code()
+    False_Code(*False_Argument_List)
 
 def For_Loop(List, Code, PassElement, *Arguments):
   for Element in List:
@@ -157,4 +169,27 @@ def Values_To_List(*Values):
   return List(Values)
 
 def Function_Creator(Argument_List, Lambda_List):
-  For_Loop(Lambda_List, Invoke_Function, true, *Argument_List)
\ No newline at end of file
+  For_Loop(Lambda_List, Invoke_Function, true, *Argument_List)
+
+def Class_Creator(Class_Property_List, Class_Values_List, Instance_Property_List, String_Representation):
+  class Class:
+    @classmethod
+    def Set_Class_Properties(Cls):
+      nonlocal Class_Property_List, Class_Values_List
+      
+      for Position in Range(Len(Class_Property_List)):
+        setattr(Cls, Class_Property_List[Position], Class_Values_List[Position])
+    
+    def __init__(Self, *Properties):
+      nonlocal Instance_Property_List
+      
+      for Position in Range(Len(Instance_Property_List)):
+        setattr(Self, Instance_Property_List[Position], Properties[Position])
+    
+    def __str__(Self):
+      nonlocal String_Representation
+      
+      return eval("f'" + String_Representation + "'")
+  
+  Class.Set_Class_Properties()
+  return Class
\ No newline at end of file
